#ifndef _DEFAULT_BADGE_H_
#define _DEFAULT_BADGE_H_

/* Définition des textes, positions X / Y et options d'affichage.
   F5FDR - 06/02/2023

	NOTE IMPORTANTES :
	
	Les recommandations décrites ici sont valables pour l'édition /
	modification des paramètres par défaut utilisés pour la compilation
	du programme via l'IDE et/ou l'édition des paramètres contenus dans
	le fichier "badge.json" de la carte SD.

	Vous ne devez modifier que les informations situées à droite
	du signe "=" et respecter systématiquement la syntaxe déjà définie.
	
	- Le texte doit toujours être entre les deux "  " et il ne
	  doit pas dépasser le nombre de caractères indiqué en commentaire.
	  
	  Exp: = "TITRE BADGE  20xx";			// 17 caractères MAX
	 
	  Important ! Les polices de caractères utilisées n'autorisent pas
	  les caractères accentués.
	  
	- La position "X" du texte doit être une valeur comprise toujours
	  entre les valeurs définies pour l'axe X c'est à dire entre 1 et 212.
	  Cette valeur doit être positive et correspondre à la position la
	  plus à gauche du premier caractère du texte à afficher.

	- La position "Y" du texte doit être, elle aussi, comprise toujours
	  entre les valeurs définies pour l'axe Y qui sont de 1 à 104.
	  Cette valeur doit être positive et correspondre à la position la
	  plus haute et a gauche du premier caractère du texte à afficher.
	  
	- L'option "xxxEnable" est une variable de type ON/OFF où "false"
	  correspond à OFF (pas d'affichage) et "true" à ON (affichage du
	  texte autorisé). Vous ne devez mettre que l'une de ces deux types
	  de valeurs "true" ou "false".
	  
	  ATTENTION ! Lors de la définition de cette même option dans pour
				  le fichier "badge.JSON", ce n'est pas le texte "true"
				  ou "false qui vous faudra écrire mais les valeurs "0"
				  ou "1". Le texte "false" correspond à la valeur "0"
				  et le texte "true" à la valeur "1"
				  
	- L'option "bLGReverse" est une variable de type ON/OFF qui permet
	  d'inverser l'affichage du logo du REF. Voir le commentaire associé
	  à cette variable sur la ligne concernée.
	  
	- La variable "acronymHeight" permet de gérer l'espace entre deux
	  caractères superposés du SIGLE (acronyme) qui est toujours écris
	  verticalement. Cette valeur est un "offset" qui sera ajouté à la
	  valeur de l'axe Y pour le prochain caractère à écrire.
	  
	NOTEZ que pour cette version V2 il n'est pas possible de modifier
	simplement les polices de caractères pour les non initiés à la
	programmation. Sachez néamois qu'elles sont fixées mais qu'il reste
	possible, si vous maitrisez l'environement Arduino et le language C,
	d'en ajouter / modifier via le fichier "badgeV2.h".
	  
*/

  // Définir ici le titre du badge
  const char    titleString[]         = "TITRE BADGE  20xx";		// 17 caractères MAX
  const int     cTitle_X              = 14;
  const int     cTitle_Y              = 18;
  const bool    bTLEnable             = true;

  // Définit ici votre indicatif
  const char    callSign[]            = "F5xxx";					// 7 caractères MAX
  const int     cSign_X               = 80;
  const int     cSign_Y               = 65;
  const bool    bCSEnable             = true;
  
  const char    qthLoc[]              = "JNnnCC";					// 7 caractère MAX
  const int     qthLoc_X              = 170;
  const int     qthLoc_Y              = 116;
  const bool    bQLEnable             = false;
  
  const char    firstName[]           = "Prenom";					// 22 caractères MAX
  const int     fName_X               = 103;
  const int     fName_Y               = 90;
  const bool    bNEnable              = true;
  
  const char    refNumber[]           = "00000";					// 6 caractères MAX
  const int     refNum_X              = 10;
  const int     refNum_Y              = 116;
  const bool    bRefRegister          = false;						// Mettre à "false" si on ne veut pas afficher son n° d'adhérent au REF nationnal

  const int     logoPos_X             = 1;
  const int     logoPos_Y             = 26;
  const bool    bLGReverse            = false;        				// Affichage en mode normal (false) ou inverse (true) du logo
  const bool    bLGEnable             = true;         				// Active ou non l'affichage du logo

  const char    acronym[]             = "ABCD";						// 4 caractère MAX
  const int     acronym_X             = 230;
  const int     acronym_Y             = 38;
  const int     acronymHeight         = 19;           				// Hauteur pour le décalage et la superposition des caractères du sigle
  const bool    bAMEnable             = true;         				// Mettre a "false" si on n'est pas inscrit a l'IDRE

  const char    freetext[]            = "myaddress@provider.com";	// 22 caractères MAX
  const int     freetext_X            = 1;
  const int     freetext_Y            = 116;
  const bool    bFTEnable             = true;
  
#endif  //_DEFAULT_BADGE_H_
